"use strict";

exports.__esModule = true;
exports.createContext = createContext;
exports.getValidChildren = getValidChildren;
exports.isObjectComponent = isObjectComponent;

var _utils = require("@chakra-ui/utils");

var _vue = require("vue");

/**
 * Creates a named context, provider, and hook.
 *
 * @param options create context options
 */
function createContext(options) {
  if (options === void 0) {
    options = {};
  }

  var _options = options,
      _options$strict = _options.strict,
      strict = _options$strict === void 0 ? true : _options$strict,
      _options$errorMessage = _options.errorMessage,
      errorMessage = _options$errorMessage === void 0 ? 'useContext: `context` is undefined. Seems you forgot to wrap component within the Provider' : _options$errorMessage,
      name = _options.name;
  var contextSymbol = Symbol(name + "Symbol");

  function Provider(payload) {
    (0, _vue.provide)(contextSymbol, payload);
  }

  function useContext() {
    var context = (0, _vue.inject)(contextSymbol, null);

    if (!context && strict) {
      throw new Error(errorMessage);
    }

    return context;
  }

  return [Provider, useContext];
}
/**
 * Gets only the valid children of a component,
 * and ignores any nullish or falsy child.
 *
 * @param slots vue slots
 *
 * see https://github.com/vuejs/vue-next/blob/HEAD/packages/runtime-core/src/helpers/renderSlot.ts
 */


function getValidChildren(slots) {
  var slotArray = (slots == null ? void 0 : slots["default"] == null ? void 0 : slots["default"]()) || [];
  return slotArray.filter(function (child) {
    return (0, _vue.isVNode)(child);
  });
}

/** Checkes whether a provided object is a component */
function isObjectComponent(subject) {
  var validComponentTypes = ['function', 'object'];
  if (!validComponentTypes.includes(typeof subject)) return false; // Is sub

  if ((0, _utils.isObject)(subject)) {
    // Is object component with render function
    if (typeof (subject == null ? void 0 : subject.render) === 'function' && (0, _vue.isVNode)(subject.render())) return true; // Is object component with setup function
    else if (typeof (subject == null ? void 0 : subject.setup) === 'function') return true;
  }

  return false;
}
//# sourceMappingURL=vue-utils.js.map